@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheResponse.h 2859 2008-04-12 14:30:08Z svn $
+ * $Id: ApacheResponse.h 2888 2008-05-07 12:23:50Z svn $
  *****************************************************************************/
 
 #ifndef APACHE_RESPONSE_H
@@ -242,27 +242,32 @@ public:
         ap_set_etag(r);
 #endif
     };
-    static void set_content_type(Handle *r)
+    static void set_content_type(Handle *r, const char *file_mime,
+                                 bool prefer_magick)
     {
+        if (prefer_magick) {
 #if AP_SERVER_MAJORVERSION_NUMBER == 1
-        r->r->content_type = NULL;
+            r->r->content_type = NULL;
 
-        // MEMO: run mod_mime{_magick} again
-        ap_find_types(r->r);
+            // MEMO: run mod_mime{_magick} again
+            ap_find_types(r->r);
 
-        if (r->r->content_type == NULL) {
-            set_content_type(r, "application/octet-stream");
-        }
+            if (r->r->content_type == NULL) {
+                set_content_type(r, file_mime);
+            }
 #else
-        r->content_type = NULL;
+            r->content_type = NULL;
 
-        // MEMO: run mod_mime{_magick} again
-        ap_run_type_checker(r);
+            // MEMO: run mod_mime{_magick} again
+            ap_run_type_checker(r);
 
-        if (r->content_type == NULL) {
-            set_content_type(r, "application/octet-stream");
-        }
+            if (r->content_type == NULL) {
+                set_content_type(r, file_mime);
+            }
 #endif
+        } else {
+            set_content_type(r, file_mime);
+        }
     };
     static void set_content_type(Handle *r, const char *content_type)
     {
