@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: CGIResponse.h 2864 2008-04-12 15:22:23Z svn $
+ * $Id: CGIResponse.h 2895 2008-07-15 16:39:11Z svn $
  *****************************************************************************/
 
 #ifndef CGI_RESPONSE_H
@@ -135,9 +135,14 @@ public:
     {
 
     };
-    static void set_content_type(Handle *r, const char *content_type)
+    static void set_content_type(Handle *r, const char *file_mime,
+                                 bool prefer_magick)
     {
-        std::cout << "Content-type: " << content_type << "\r\n";
+        set_content_type(r, file_mime);
+    };
+    static void set_content_type(Handle *r, const char *file_mime)
+    {
+        std::cout << "Content-type: " << file_mime << "\r\n";
     };
     static void set_accept_ranges(Handle *r)
     {
