@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Environment.h 2756 2007-12-11 10:57:59Z svn $
+ * $Id: Environment.h 2898 2008-07-17 14:34:38Z svn $
  *****************************************************************************/
 
 #ifndef ENVIRONMENT_H
@@ -39,7 +39,12 @@
 #include "mod_uploader_config.h"
 
 #ifdef APACHE_HTTPD_H
+#ifdef AP_SERVER_MAJORVERSION
+// Apache 2.0 系の若いバージョンもの
+#define AP_SERVER_MAJORVERSION_NUMBER 2
+#endif
 #ifndef AP_SERVER_MAJORVERSION_NUMBER
+// Apache 1.3 系
 #define AP_SERVER_MAJORVERSION_NUMBER 1
 #endif
 #endif
