@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Macro.h 2820 2008-03-15 11:00:10Z svn $
+ * $Id: Macro.h 2873 2008-04-27 14:19:47Z svn $
  *****************************************************************************/
 
 /**
@@ -187,6 +187,26 @@
  * ワードサイズを定義したマクロ．
  */
 #define WORD_SIZE (sizeof(int))
+/**
+ * GCC の警告を避けるためのマクロ．
+ *
+ * 具体的には，ARM architecture 等で「increases required alignment of
+ * target type」が出るのを防止します．
+ *
+ * @see gcc/c-typeck.c
+ */
+#ifdef __GNUC__
+#define AVOID_ALIGN_WARN (void *)
+#else
+#define AVOID_ALIGN_WARN
+#endif
+/**
+ * n * den が num 以上となる最小の n を計算するマクロ．
+ *
+ * @param[in] num 被除数
+ * @param[in] den 除数
+ */
+#define PAD_DIV(num, den) ((num+den-1)/den)
 /**
  * ポインタを char * にキャストするマクロ．
  *
