@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ReadLocker.h 2756 2007-12-11 10:57:59Z svn $
+ * $Id: ReadLocker.h 2822 2008-03-15 14:41:22Z svn $
  *****************************************************************************/
 
 #ifndef READ_LOCKER_H
@@ -44,7 +44,11 @@ public:
      *
      * @param[in] lock ロック変数
      */
-    ReadLocker(apr_atomic_t *lock)
+    ReadLocker(apr_atomic_t *lock
+#ifdef DEBUG_ReadWriteLocker
+               , apr_thread_mutex_t *mutex
+#endif
+               )
       : ReadWriteLocker()
     {
         apr_size_t try_count;
@@ -58,7 +62,11 @@ public:
             if (LIKELY(can_lock(curr_status))) {
                 new_status = curr_status + READ_COUNT_UINIT;
                 prev_status = apr_atomic_cas(lock, new_status, curr_status);
-                init(lock, new_status);
+                init(lock, new_status
+#ifdef DEBUG_ReadWriteLocker
+                     , mutex
+#endif
+                     );
                 if (prev_status == curr_status) {
                     log_try_count("ReadLock",
                                   try_count, curr_status, new_status);
@@ -70,7 +78,11 @@ public:
                 new_status = (curr_status & (~READ_COUNT_MASK)) | READ_COUNT_UINIT;
                 new_status += AGE_UINIT;
                 prev_status = apr_atomic_cas(lock, new_status, curr_status);
-                init(lock, new_status);
+                init(lock, new_status
+#ifdef DEBUG_ReadWriteLocker
+                     , mutex
+#endif
+                     );
                 if (prev_status == curr_status) {
                     log_try_count("ReadLock(TIME OUT)",
                                   try_count, curr_status, new_status);
