@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateVariableCreator.h 2756 2007-12-11 10:57:59Z svn $
+ * $Id: TemplateVariableCreator.h 2873 2008-04-27 14:19:47Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_VARIABLE_CREATOR_H
@@ -102,8 +102,8 @@ private:
     const char **ids_;
     variable_t **variables_;
 
-    char *var_scr_pool_;
-    char *var_scr_pool_end_;
+    long *var_scr_pool_;
+    long *var_scr_pool_end_;
 };
 
 #endif
