@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.h 2772 2008-01-24 16:25:23Z svn $
+ * $Id: UploadItemManager.h 2907 2009-01-14 12:56:44Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_MANAGER_H
@@ -68,6 +68,16 @@ public:
     {
         return *mtime_;
     };
+    void set_mtime(apr_time_t mtime)
+    {
+        *mtime_ = mtime;
+    };
+    void update_mtime(apr_time_t mtime)
+    {
+        if (mtime > *mtime_) {
+            set_mtime(mtime);
+        }
+    };
     /**
      * 共有メモリを使ってインスタンスを生成します．
      *
