@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemReader.h 2756 2007-12-11 10:57:59Z svn $
+ * $Id: UploadItemReader.h 2813 2008-03-07 14:35:04Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_READER_H
@@ -65,15 +65,6 @@ public:
      * @param[out] uitem アイテムデータ
      */
     void read(apr_size_t item_id, UploadItem *uitem);
-    /**
-     * アイテムを読み出します．
-     *
-     * @param[in] item_id アイテムの ID
-     * @param[out] uitem アイテムデータ
-     * @param[out] uitem_file アイテムファイル
-     */
-    void read(apr_size_t item_id, UploadItem **uitem,
-              apr_pool_t *pool, File& uitem_file) const;
     /**
      * アイテムが存在するかどうか調べます．
      *
@@ -95,10 +86,10 @@ public:
                            apr_size_t item_id);
 
 private:
-    void read_and_check(File *uitem_file,
-                        apr_mmap_t **uitem_file_map) const;
+    static apr_size_t read_and_check(File *uitem_file,
+                                     apr_mmap_t **uitem_file_map);
 
-    static void check_format(apr_mmap_t *uitem_file_map);
+    static apr_size_t check_format(apr_mmap_t *uitem_file_map);
 };
 
 #endif
