@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.h 2768 2007-12-16 13:03:37Z svn $
+ * $Id: UploaderConfig.h 2907 2009-01-14 12:56:44Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_CONFIG_H
@@ -122,18 +122,15 @@ public:
     {
         return post_progress_list_;
     };
-    UploaderTemplate *get_template(template_type_t type)
+    UploaderTemplate *get_template(template_type_t type) const
     {
-        if (UNLIKELY(is_debug_mode)) {
-            update_template(type);
-        }
-
         return tmpls_[type];
     };
     bool is_active() const
     {
         return is_active_;
     };
+    void update_template();
 
     const char *to_string(apr_pool_t *pool);
 
@@ -155,7 +152,6 @@ private:
     void check_dir(const char *dir_path);
     void check_template();
     void load_template();
-    void update_template(template_type_t type);
     const char *config_to_string(apr_pool_t *pool);
 
     apr_pool_t *pool_;
