@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderTemplate.h 2772 2008-01-24 16:25:23Z svn $
+ * $Id: UploaderTemplate.h 2907 2009-01-14 12:56:44Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_TEMPLATE_H
@@ -53,7 +53,7 @@ public:
 
     void load();
     void load(const char *file_path);
-    void update();
+    bool update();
 
     const TemplateParser::node_t *get_node_tree() const
     {
@@ -75,6 +75,10 @@ public:
     {
         return key_count_;
     };
+    apr_time_t get_mtime() const
+    {
+        return mtime_;
+    };
     UploadItemVariableCreator *get_item_var_creator() const
     {
         return item_var_creator_;
