@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ApacheRequestReader.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: ApacheRequestReader.cpp 2883 2008-05-02 12:59:25Z svn $
  *****************************************************************************/
 
 #include "ApacheRequestReader.h"
@@ -38,7 +38,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ApacheRequestReader.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: ApacheRequestReader.cpp 2883 2008-05-02 12:59:25Z svn $");
 
 const apr_size_t ApacheRequestReader::READ_SLEEP_FACTOR = 16;
 const apr_size_t ApacheRequestReader::READ_SLEEP_USEC   = 100000;
@@ -67,7 +67,7 @@ void ApacheRequestReader::read(char *buffer, apr_size_t size, apr_size_t *read_s
         return;
     }
 
-    if ((*read_size = ap_get_client_block(request_->r, buffer, size)) == 0) {
+    if ((*read_size = ap_get_client_block(request_->r, buffer, static_cast<int>(size))) == 0) {
         is_eos_ = true;
     }
 }
