@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: DownloadFlowController.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: DownloadFlowController.cpp 2813 2008-03-07 14:35:04Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -35,7 +35,7 @@
 #include "WriteLocker.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: DownloadFlowController.cpp 2813 2008-03-07 14:35:04Z svn $");
 
 const apr_size_t DownloadSession::DOWNLOAD_BUSY_SLEEP_SEC   = 5;
 
@@ -209,7 +209,7 @@ DownloadFlowController::downloader_list_get(apr_sockaddr_t *sockaddr)
 const char *DownloadFlowController::dump_downloader(apr_pool_t *pool,
                                                     downloader_t *downloader)
 {
-    return apr_psprintf(pool, "%24s : %u\n",
+    return apr_psprintf(pool, "%24s : %" APR_SIZE_T_FMT "\n",
                         &(downloader->paddress[1]), downloader->session_count);
 }
 
