@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateLexer.cpp 2889 2008-05-10 16:36:45Z svn $
+ * $Id: TemplateLexer.cpp 2907 2009-01-14 12:56:44Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -44,7 +44,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: TemplateLexer.cpp 2889 2008-05-10 16:36:45Z svn $");
+SOURCE_INFO_ADD("$Id: TemplateLexer.cpp 2907 2009-01-14 12:56:44Z svn $");
 
 #define AS_TOKEN(pointer)           reinterpret_cast<token_t *>(pointer)
 #define AS_TOKEN_P(pointer)         reinterpret_cast<token_t **>(pointer)
@@ -444,11 +444,15 @@ bool TemplateLexer::get_next_str_token()
 
     while ((input_.top != str_end) &&
            ((var_start = strnchr(input_.top, str_end - input_.top,
-                                 VARIABLE_C)) != NULL) && // 変数記号を探索
-           !((var_start != input_.top) && // 直前にエスケープがある場合を除外
-             *(var_start-1) == ESCAPE_C)) {
-
-        if ((var_start+1) == str_end) { // 変数記号で終了るのはおかしい
+                                 VARIABLE_C)) != NULL)) { // 変数記号を探索
+        if ((var_start != input_.top) &&
+            *(var_start-1) == ESCAPE_C) { // 直前にエスケープがある場合を除外
+            push_token(create_str_token(input_.top, var_start - input_.top-1));
+            push_token(create_token(COMMA));
+            input_.top = var_start + 1;
+            continue;
+        }
+        if ((var_start+1) == str_end) { // 変数記号で終わるのはおかしい
             DUMP_TOKEN_AND_THROW(MESSAGE_TMPL_VARIABLE_ENDED);
         }
 
