@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.cpp 2772 2008-01-24 16:25:23Z svn $
+ * $Id: UploadItemManager.cpp 2907 2009-01-14 12:56:44Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -49,7 +49,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2772 2008-01-24 16:25:23Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2907 2009-01-14 12:56:44Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
@@ -292,7 +292,7 @@ apr_size_t UploadItemManager::add_impl(apr_pool_t *pool,
         }
         item_list_->add(uitem);
 
-        *mtime_ = current_time;
+        set_mtime(current_time);
     }
 
     // 2 回に分けてロックしているので，最悪の場合を考えると必要
@@ -312,7 +312,7 @@ void UploadItemManager::remove_impl(apr_pool_t *pool, UploadItem *uitem)
     item_list_->remove(uitem->get_id());
     thumbnail_list_->remove(uitem->get_id());
 
-    *mtime_ = apr_time_now();
+    set_mtime(apr_time_now());
 }
 
 void UploadItemManager::remove_files(apr_pool_t *pool,
