@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemRss.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: UploadItemRss.cpp 2893 2008-05-24 13:18:29Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -36,11 +36,11 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: UploadItemRss.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemRss.cpp 2893 2008-05-24 13:18:29Z svn $");
 #endif
 
 template<class W> const char
-UploadItemRss<W>::CONTENT_TYPE[]      = "application/xml; charset=EUC-JP";
+UploadItemRss<W>::CONTENT_TYPE[]      = "application/xml; charset=" SYS_CHARACTER_CODE;
 template<class W> const apr_size_t
 UploadItemRss<W>::MAX_TIME_SIZE       = sizeof("0000-00-00T00:00:00+09:00");
 template<class W> const char
@@ -65,7 +65,7 @@ void UploadItemRss<W>::print(apr_pool_t *pool, const char *base_url,
 {
     UploadItem *uitem;;
 
-    print("<?xml version=\"1.0\" encoding=\"EUC-JP\"?>\n");
+    print("<?xml version=\"1.0\" encoding=\"" SYS_CHARACTER_CODE "\"?>\n");
     print("<rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\"\n");
     print("         xmlns=\"http://purl.org/rss/1.0/\"\n");
     print("         xmlns:dc=\"http://purl.org/dc/elements/1.1/\">\n");
