@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemVariableCreator.cpp 2756 2007-12-11 10:57:59Z svn $
+ * $Id: UploadItemVariableCreator.cpp 2875 2008-04-27 14:42:48Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -32,7 +32,7 @@
 #include "Auxiliary.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemVariableCreator.cpp 2756 2007-12-11 10:57:59Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemVariableCreator.cpp 2875 2008-04-27 14:42:48Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -54,15 +54,17 @@ UploadItemVariableCreator::create(apr_pool_t *pool,
 
     // メモリを一気に確保
     APR_PALLOC(memory, void *, pool,
-               sizeof(variable_t) +
-               get_item_array_memory_size(item_iter->size()) +
+               PAD_DIV(sizeof(variable_t) +
+                       get_item_array_memory_size(item_iter->size()),
+                       sizeof(variable_t)) * sizeof(variable_t) +
                (get_item_memory_size() * item_iter->size()));
 
     item_array_memory = AS_VARIABLE(memory);
     item_memory
-        = AS_SCALAR(AS_CHAR(item_array_memory) +
-                    sizeof(variable_t) +
-                    get_item_array_memory_size(item_iter->size()));
+        = AS_SCALAR(item_array_memory +
+                    PAD_DIV(sizeof(variable_t) +
+                            get_item_array_memory_size(item_iter->size()),
+                            sizeof(variable_t)));
 
     var = item_array_memory++;
     var->type = TemplateVariable::ARRAY;
