@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderConfig.cpp 2768 2007-12-16 13:03:37Z svn $
+ * $Id: UploaderConfig.cpp 2907 2009-01-14 12:56:44Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -46,7 +46,7 @@
 #include "Message.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2768 2007-12-16 13:03:37Z svn $");
+SOURCE_INFO_ADD("$Id: UploaderConfig.cpp 2907 2009-01-14 12:56:44Z svn $");
 
 #define PARAM_PREFIX "Uploader"
 
@@ -166,7 +166,6 @@ void UploaderConfig::init()
     }
 
     check();
-    load_template();
 
     item_list_shm_ = create_shm
         (pool_, UploadItemList::get_memory_size(total_file_number_limit));
@@ -198,6 +197,8 @@ void UploaderConfig::init()
     post_progress_list_ = PostProgressList::get_instance
         (post_progress_list_shm_);
 
+    load_template();
+
     is_active_ = true;
 }
 
@@ -243,6 +244,15 @@ void UploaderConfig::set_template(template_type_t type, const char *tmpl_file_pa
     tmpls_[type] = new UploaderTemplate(pool_, tmpl_file_path);
 }
 
+void UploaderConfig::update_template()
+{
+    for (apr_size_t i = 0; i < ARRAY_SIZE_OF(tmpls_); i++) {
+        if (tmpls_[i]->update()) {
+            get_item_manager()->update_mtime(tmpls_[i]->get_mtime());
+        }
+    }
+}
+
 const char *UploaderConfig::to_string(apr_pool_t *pool)
 {
     return apr_pstrcat
@@ -301,14 +311,10 @@ void UploaderConfig::load_template()
 {
     for (apr_size_t i = 0; i < ARRAY_SIZE_OF(tmpls_); i++) {
         tmpls_[i]->load();
+        get_item_manager()->update_mtime(tmpls_[i]->get_mtime());
     }
 }
 
-void UploaderConfig::update_template(template_type_t type)
-{
-    tmpls_[type]->update();
-}
-
 const char *UploaderConfig::config_to_string(apr_pool_t *pool)
 {
     return apr_pstrcat
