@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: mod_uploader.cpp 2894 2008-07-15 16:29:54Z svn $
+ * $Id: mod_uploader.cpp 2907 2009-01-14 12:56:44Z svn $
  *****************************************************************************/
 
 /**
@@ -65,7 +65,7 @@
 
 using namespace std;
 
-SOURCE_INFO_ADD("$Id: mod_uploader.cpp 2894 2008-07-15 16:29:54Z svn $");
+SOURCE_INFO_ADD("$Id: mod_uploader.cpp 2907 2009-01-14 12:56:44Z svn $");
 
 static const char *HANDLER_NAME = "uploader";
 static apr_array_header_t *uploader_config_array = NULL;
@@ -377,6 +377,10 @@ static int uploader_handler(request_rec *r)
     }
 
     try {
+        if (UNLIKELY(config->is_debug_mode)) {
+            config->update_template();
+        }
+
         return uploader_command_handler<ApacheResponse>(r, config,
                                                         r->path_info);
     } catch(const char *message) {
