@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2894 2008-07-15 16:29:54Z svn $
+ * $Id: uploader_handler.cpp 2907 2009-01-14 12:56:44Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -57,7 +57,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2894 2008-07-15 16:29:54Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2907 2009-01-14 12:56:44Z svn $");
 #endif
 
 #define STR_CMP_LITERAL(arg, literal)                            \
@@ -1146,7 +1146,7 @@ static int remove(typename Response::Handle *r, UploaderConfig *config,
             return redirect<Response>
                 (r, o,
                  apr_pstrcat(r->pool, config->base_url, ARG_SEPARATE_STR,
-                             ADMIN_COMMAND, ARG_SEPARATE_STR, NULL));
+                             ADMIN_COMMAND, ARG_SEPARATE_STR, arg, NULL));
         } else {
             Response::set_env(r, "uploader_remove", "");
             Response::set_env(r, "uploader_item_id",
