@@ -138,8 +138,19 @@ sub make_check {
     $exp->expect(MAKE_TIMEOUT_SEC, 'src>');
 }
 
+sub make_test {
+    my $exp = shift;
+    my $cc = shift;
+    my $test = shift;
+
+    $exp->send('make -f GNUmakefile.win32 ' . $test . '.run CC=' . $cc. "\n");
+    $exp->expect(MAKE_TIMEOUT_SEC, 'src>');
+}
+
 my $user = $ENV{'USER'};
 my $cc   = shift @ARGV || 'cl';
+my $test = shift @ARGV;
+my $repeat = shift @ARGV || 1;
 my $pass = $ENV{'WIN_PASS'} || get_pass();
 my $exp = create_exp();
 
@@ -166,8 +177,13 @@ init_tree($exp);
 cd_src_dir($exp);
 # ĶѿΥå
 set_env($exp, $cc);
-# ѥ
-make_check($exp, $cc);
+if (defined $test) {
+    foreach (1..$repeat) {
+        make_test($exp, $cc, $test);
+    }
+} else {
+    make_check($exp, $cc);
+}
 exit_cmd($exp);
 
 `rm -rf work $temp_dir`;
