@@ -86,6 +86,9 @@
             this.perPageItemNumberNumericUpDown = new System.Windows.Forms.NumericUpDown();
             this.fileSizeLimitNumericUpDown = new System.Windows.Forms.NumericUpDown();
             this.tabPage3 = new System.Windows.Forms.TabPage();
+            this.infoTmplPathButton = new System.Windows.Forms.Button();
+            this.infoTmplPathTextBox = new System.Windows.Forms.TextBox();
+            this.infoTmplPathLabel = new System.Windows.Forms.Label();
             this.errorTmplPathLabel = new System.Windows.Forms.Label();
             this.errorTmplPathTextBox = new System.Windows.Forms.TextBox();
             this.errorTmplPathButton = new System.Windows.Forms.Button();
@@ -107,8 +110,6 @@
             this.toolStripSeparator1 = new System.Windows.Forms.ToolStripSeparator();
             this.helpStripButton = new System.Windows.Forms.ToolStripButton();
             this.copyButton = new System.Windows.Forms.Button();
-            this.bindingSource1 = new System.Windows.Forms.BindingSource(this.components);
-            ((System.ComponentModel.ISupportInitialize)(this.uploaderConfigBindingSource)).BeginInit();
             this.configTabControl.SuspendLayout();
             this.tabPage1.SuspendLayout();
             this.groupBox2.SuspendLayout();
@@ -124,7 +125,6 @@
             ((System.ComponentModel.ISupportInitialize)(this.errorProvider)).BeginInit();
             this.groupBox1.SuspendLayout();
             this.menuToolStrip.SuspendLayout();
-            ((System.ComponentModel.ISupportInitialize)(this.bindingSource1)).BeginInit();
             this.SuspendLayout();
             // 
             // thumbDirPathLabel
@@ -139,7 +139,7 @@
             // adminTmplPathLabel
             // 
             this.adminTmplPathLabel.AutoSize = true;
-            this.adminTmplPathLabel.Location = new System.Drawing.Point(8, 168);
+            this.adminTmplPathLabel.Location = new System.Drawing.Point(8, 208);
             this.adminTmplPathLabel.Name = "adminTmplPathLabel";
             this.adminTmplPathLabel.Size = new System.Drawing.Size(123, 12);
             this.adminTmplPathLabel.TabIndex = 12;
@@ -183,7 +183,7 @@
             // 
             // thumbnailTmplPathButton
             // 
-            this.thumbnailTmplPathButton.Location = new System.Drawing.Point(384, 144);
+            this.thumbnailTmplPathButton.Location = new System.Drawing.Point(384, 184);
             this.thumbnailTmplPathButton.Name = "thumbnailTmplPathButton";
             this.thumbnailTmplPathButton.Size = new System.Drawing.Size(56, 23);
             this.thumbnailTmplPathButton.TabIndex = 11;
@@ -267,7 +267,7 @@
             // progressTmplPathLabel
             // 
             this.progressTmplPathLabel.AutoSize = true;
-            this.progressTmplPathLabel.Location = new System.Drawing.Point(8, 48);
+            this.progressTmplPathLabel.Location = new System.Drawing.Point(8, 88);
             this.progressTmplPathLabel.Name = "progressTmplPathLabel";
             this.progressTmplPathLabel.Size = new System.Drawing.Size(176, 12);
             this.progressTmplPathLabel.TabIndex = 3;
@@ -276,7 +276,7 @@
             // downloadTmplPathLabel
             // 
             this.downloadTmplPathLabel.AutoSize = true;
-            this.downloadTmplPathLabel.Location = new System.Drawing.Point(8, 88);
+            this.downloadTmplPathLabel.Location = new System.Drawing.Point(8, 128);
             this.downloadTmplPathLabel.Name = "downloadTmplPathLabel";
             this.downloadTmplPathLabel.Size = new System.Drawing.Size(154, 12);
             this.downloadTmplPathLabel.TabIndex = 6;
@@ -285,7 +285,7 @@
             // thumbnailTmplPathLabel
             // 
             this.thumbnailTmplPathLabel.AutoSize = true;
-            this.thumbnailTmplPathLabel.Location = new System.Drawing.Point(8, 128);
+            this.thumbnailTmplPathLabel.Location = new System.Drawing.Point(8, 168);
             this.thumbnailTmplPathLabel.Name = "thumbnailTmplPathLabel";
             this.thumbnailTmplPathLabel.Size = new System.Drawing.Size(148, 12);
             this.thumbnailTmplPathLabel.TabIndex = 9;
@@ -301,7 +301,7 @@
             this.configTabControl.Location = new System.Drawing.Point(0, 32);
             this.configTabControl.Name = "configTabControl";
             this.configTabControl.SelectedIndex = 0;
-            this.configTabControl.Size = new System.Drawing.Size(456, 288);
+            this.configTabControl.Size = new System.Drawing.Size(456, 320);
             this.configTabControl.TabIndex = 1;
             this.configTabControl.SelectedIndexChanged += new System.EventHandler(this.configTabControl_SelectedIndexChanged);
             // 
@@ -313,7 +313,7 @@
             this.tabPage1.Location = new System.Drawing.Point(4, 21);
             this.tabPage1.Name = "tabPage1";
             this.tabPage1.Padding = new System.Windows.Forms.Padding(3);
-            this.tabPage1.Size = new System.Drawing.Size(448, 263);
+            this.tabPage1.Size = new System.Drawing.Size(448, 295);
             this.tabPage1.TabIndex = 0;
             this.tabPage1.Text = "基本設定";
             this.tabPage1.UseVisualStyleBackColor = true;
@@ -355,7 +355,6 @@
             this.modulePathTextBox.TabIndex = 7;
             this.modulePathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
             this.modulePathTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.modulePathTextBox_Validating);
-
             // 
             // imagemagickPathButton
             // 
@@ -385,7 +384,6 @@
             this.apachePathTextBox.TabIndex = 1;
             this.apachePathTextBox.KeyUp += new System.Windows.Forms.KeyEventHandler(this.textBox_KeyUp);
             this.apachePathTextBox.Validating += new System.ComponentModel.CancelEventHandler(this.apachePathTextBox_Validating);
-
             // 
             // apachePathLabel
             // 
@@ -465,7 +463,7 @@
             this.tabPage2.Location = new System.Drawing.Point(4, 21);
             this.tabPage2.Name = "tabPage2";
             this.tabPage2.Padding = new System.Windows.Forms.Padding(3);
-            this.tabPage2.Size = new System.Drawing.Size(448, 263);
+            this.tabPage2.Size = new System.Drawing.Size(448, 295);
             this.tabPage2.TabIndex = 1;
             this.tabPage2.Text = "フォルダ(1)";
             this.tabPage2.UseVisualStyleBackColor = true;
@@ -550,7 +548,7 @@
             this.tabPage5.Controls.Add(this.imageDirPathTextBox);
             this.tabPage5.Location = new System.Drawing.Point(4, 21);
             this.tabPage5.Name = "tabPage5";
-            this.tabPage5.Size = new System.Drawing.Size(448, 263);
+            this.tabPage5.Size = new System.Drawing.Size(448, 295);
             this.tabPage5.TabIndex = 4;
             this.tabPage5.Text = "フォルダ(2)";
             this.tabPage5.UseVisualStyleBackColor = true;
@@ -645,7 +643,7 @@
             this.tabPage4.Controls.Add(this.fileSizeLimitNumericUpDown);
             this.tabPage4.Location = new System.Drawing.Point(4, 21);
             this.tabPage4.Name = "tabPage4";
-            this.tabPage4.Size = new System.Drawing.Size(448, 263);
+            this.tabPage4.Size = new System.Drawing.Size(448, 295);
             this.tabPage4.TabIndex = 3;
             this.tabPage4.Text = "ファイル";
             this.tabPage4.UseVisualStyleBackColor = true;
@@ -720,6 +718,9 @@
             // tabPage3
             // 
             this.tabPage3.AutoScroll = true;
+            this.tabPage3.Controls.Add(this.infoTmplPathButton);
+            this.tabPage3.Controls.Add(this.infoTmplPathTextBox);
+            this.tabPage3.Controls.Add(this.infoTmplPathLabel);
             this.tabPage3.Controls.Add(this.errorTmplPathLabel);
             this.tabPage3.Controls.Add(this.errorTmplPathTextBox);
             this.tabPage3.Controls.Add(this.errorTmplPathButton);
@@ -740,15 +741,42 @@
             this.tabPage3.Controls.Add(this.indexTmplPathTextBox);
             this.tabPage3.Location = new System.Drawing.Point(4, 21);
             this.tabPage3.Name = "tabPage3";
-            this.tabPage3.Size = new System.Drawing.Size(448, 263);
+            this.tabPage3.Size = new System.Drawing.Size(448, 295);
             this.tabPage3.TabIndex = 2;
             this.tabPage3.Text = "テンプレート";
             this.tabPage3.UseVisualStyleBackColor = true;
             // 
+            // infoTmplPathButton
+            // 
+            this.infoTmplPathButton.Location = new System.Drawing.Point(384, 64);
+            this.infoTmplPathButton.Name = "infoTmplPathButton";
+            this.infoTmplPathButton.Size = new System.Drawing.Size(56, 23);
+            this.infoTmplPathButton.TabIndex = 21;
+            this.infoTmplPathButton.Text = "参照";
+            this.infoTmplPathButton.UseVisualStyleBackColor = true;
+            this.infoTmplPathButton.Click += new System.EventHandler(this.infoTmplPathButton_Click);
+            // 
+            // infoTmplPathTextBox
+            // 
+            this.infoTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "infoTmplPath", true));
+            this.infoTmplPathTextBox.Location = new System.Drawing.Point(8, 64);
+            this.infoTmplPathTextBox.Name = "infoTmplPathTextBox";
+            this.infoTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
+            this.infoTmplPathTextBox.TabIndex = 20;
+            // 
+            // infoTmplPathLabel
+            // 
+            this.infoTmplPathLabel.AutoSize = true;
+            this.infoTmplPathLabel.Location = new System.Drawing.Point(8, 48);
+            this.infoTmplPathLabel.Name = "infoTmplPathLabel";
+            this.infoTmplPathLabel.Size = new System.Drawing.Size(200, 12);
+            this.infoTmplPathLabel.TabIndex = 19;
+            this.infoTmplPathLabel.Text = "アップロード完了通知ページのテンプレート";
+            // 
             // errorTmplPathLabel
             // 
             this.errorTmplPathLabel.AutoSize = true;
-            this.errorTmplPathLabel.Location = new System.Drawing.Point(8, 208);
+            this.errorTmplPathLabel.Location = new System.Drawing.Point(8, 248);
             this.errorTmplPathLabel.Name = "errorTmplPathLabel";
             this.errorTmplPathLabel.Size = new System.Drawing.Size(126, 12);
             this.errorTmplPathLabel.TabIndex = 18;
@@ -757,7 +785,7 @@
             // errorTmplPathTextBox
             // 
             this.errorTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "errorTmplPath", true));
-            this.errorTmplPathTextBox.Location = new System.Drawing.Point(8, 224);
+            this.errorTmplPathTextBox.Location = new System.Drawing.Point(8, 264);
             this.errorTmplPathTextBox.Name = "errorTmplPathTextBox";
             this.errorTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
             this.errorTmplPathTextBox.TabIndex = 17;
@@ -765,7 +793,7 @@
             // 
             // errorTmplPathButton
             // 
-            this.errorTmplPathButton.Location = new System.Drawing.Point(384, 224);
+            this.errorTmplPathButton.Location = new System.Drawing.Point(384, 264);
             this.errorTmplPathButton.Name = "errorTmplPathButton";
             this.errorTmplPathButton.Size = new System.Drawing.Size(56, 23);
             this.errorTmplPathButton.TabIndex = 15;
@@ -775,7 +803,7 @@
             // 
             // adminTmplPathButton
             // 
-            this.adminTmplPathButton.Location = new System.Drawing.Point(384, 184);
+            this.adminTmplPathButton.Location = new System.Drawing.Point(384, 224);
             this.adminTmplPathButton.Name = "adminTmplPathButton";
             this.adminTmplPathButton.Size = new System.Drawing.Size(56, 23);
             this.adminTmplPathButton.TabIndex = 14;
@@ -785,7 +813,7 @@
             // adminTmplPathTextBox
             // 
             this.adminTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "adminTmplPath", true));
-            this.adminTmplPathTextBox.Location = new System.Drawing.Point(8, 184);
+            this.adminTmplPathTextBox.Location = new System.Drawing.Point(8, 224);
             this.adminTmplPathTextBox.Name = "adminTmplPathTextBox";
             this.adminTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
             this.adminTmplPathTextBox.TabIndex = 13;
@@ -793,7 +821,7 @@
             // 
             // downloadTmplPathButton
             // 
-            this.downloadTmplPathButton.Location = new System.Drawing.Point(384, 104);
+            this.downloadTmplPathButton.Location = new System.Drawing.Point(384, 144);
             this.downloadTmplPathButton.Name = "downloadTmplPathButton";
             this.downloadTmplPathButton.Size = new System.Drawing.Size(56, 23);
             this.downloadTmplPathButton.TabIndex = 8;
@@ -803,7 +831,7 @@
             // 
             // progressTmplPathButton
             // 
-            this.progressTmplPathButton.Location = new System.Drawing.Point(384, 64);
+            this.progressTmplPathButton.Location = new System.Drawing.Point(384, 104);
             this.progressTmplPathButton.Name = "progressTmplPathButton";
             this.progressTmplPathButton.Size = new System.Drawing.Size(56, 23);
             this.progressTmplPathButton.TabIndex = 5;
@@ -824,7 +852,7 @@
             // thumbnailTmplPathTextBox
             // 
             this.thumbnailTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "thumbnailTmplPath", true));
-            this.thumbnailTmplPathTextBox.Location = new System.Drawing.Point(8, 144);
+            this.thumbnailTmplPathTextBox.Location = new System.Drawing.Point(8, 184);
             this.thumbnailTmplPathTextBox.Name = "thumbnailTmplPathTextBox";
             this.thumbnailTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
             this.thumbnailTmplPathTextBox.TabIndex = 10;
@@ -833,7 +861,7 @@
             // downloadTmplPathTextBox
             // 
             this.downloadTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "downloadTmplPath", true));
-            this.downloadTmplPathTextBox.Location = new System.Drawing.Point(8, 104);
+            this.downloadTmplPathTextBox.Location = new System.Drawing.Point(8, 144);
             this.downloadTmplPathTextBox.Name = "downloadTmplPathTextBox";
             this.downloadTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
             this.downloadTmplPathTextBox.TabIndex = 7;
@@ -842,7 +870,7 @@
             // progressTmplPathTextBox
             // 
             this.progressTmplPathTextBox.DataBindings.Add(new System.Windows.Forms.Binding("Text", this.uploaderConfigBindingSource, "progressTmplPath", true));
-            this.progressTmplPathTextBox.Location = new System.Drawing.Point(8, 64);
+            this.progressTmplPathTextBox.Location = new System.Drawing.Point(8, 104);
             this.progressTmplPathTextBox.Name = "progressTmplPathTextBox";
             this.progressTmplPathTextBox.Size = new System.Drawing.Size(360, 19);
             this.progressTmplPathTextBox.TabIndex = 4;
@@ -865,7 +893,7 @@
             // groupBox1
             // 
             this.groupBox1.Controls.Add(this.apache_config_textTextBox);
-            this.groupBox1.Location = new System.Drawing.Point(0, 368);
+            this.groupBox1.Location = new System.Drawing.Point(0, 400);
             this.groupBox1.Name = "groupBox1";
             this.groupBox1.Size = new System.Drawing.Size(456, 176);
             this.groupBox1.TabIndex = 3;
@@ -897,7 +925,6 @@
             this.menuToolStrip.Size = new System.Drawing.Size(457, 25);
             this.menuToolStrip.TabIndex = 0;
             this.menuToolStrip.Text = "toolStrip1";
-
             // 
             // copyToolStripButton
             // 
@@ -939,7 +966,7 @@
             // 
             this.copyButton.BackColor = System.Drawing.SystemColors.Control;
             this.copyButton.Font = new System.Drawing.Font("MS UI Gothic", 11.25F, System.Drawing.FontStyle.Bold, System.Drawing.GraphicsUnit.Point, ((byte)(128)));
-            this.copyButton.Location = new System.Drawing.Point(0, 328);
+            this.copyButton.Location = new System.Drawing.Point(0, 360);
             this.copyButton.Name = "copyButton";
             this.copyButton.Size = new System.Drawing.Size(456, 32);
             this.copyButton.TabIndex = 2;
@@ -951,7 +978,7 @@
             // 
             this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 12F);
             this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
-            this.ClientSize = new System.Drawing.Size(457, 547);
+            this.ClientSize = new System.Drawing.Size(457, 578);
             this.Controls.Add(this.copyButton);
             this.Controls.Add(this.menuToolStrip);
             this.Controls.Add(this.groupBox1);
@@ -986,7 +1013,6 @@
             this.groupBox1.PerformLayout();
             this.menuToolStrip.ResumeLayout(false);
             this.menuToolStrip.PerformLayout();
-            ((System.ComponentModel.ISupportInitialize)(this.bindingSource1)).EndInit();
             this.ResumeLayout(false);
             this.PerformLayout();
 
@@ -1074,6 +1100,8 @@
         private System.Windows.Forms.TextBox errorTmplPathTextBox;
 
         private System.Windows.Forms.Button errorTmplPathButton;
-        private System.Windows.Forms.BindingSource bindingSource1;
+        private System.Windows.Forms.Label infoTmplPathLabel;
+        private System.Windows.Forms.Button infoTmplPathButton;
+        private System.Windows.Forms.TextBox infoTmplPathTextBox;
     }
 }
\ No newline at end of file
