@@ -5,13 +5,17 @@ use vars qw($VERSION);
 
 $VERSION = 0.01;
 
+# use Encode;
 use WWW::Mechanize;
 
-use constant LIST_RELEASE_LABEL         => '꡼ե롦ꥹ';
-use constant LIST_RELEASE_LINK_LABEL    => '꡼';
-use constant EDIT_RELEASE_LABEL         => '꡼Խ';
-use constant EDIT_RELEASE_LINK_LABEL    => 'ե꡼/ѹ';
-use constant CREATE_RELEASE_LABEL       => '꡼ο';
+use constant LIST_RELEASE_LABEL         => 'パッケージ/リリース/ファイル';
+use constant LIST_RELEASE_LINK_LABEL    => 'リリース一覧';
+use constant EDIT_RELEASE_LABEL         => 'リリースの編集';
+use constant EDIT_RELEASE_LINK_LABEL    => 'ファイルリリース管理';
+use constant CREATE_RELEASE_LABEL       => 'リリースの新規作成';
+
+# binmode STDOUT, ":encoding(euc-jp)";
+# binmode STDERR, ":encoding(euc-jp)";
 
 sub new {
     my $class = shift;
@@ -33,13 +37,13 @@ sub login {
     my $pass = shift;
 
     $self->{'mech'}->get('https://sourceforge.jp/account/login.php');
-    $self->{'mech'}->form_number(1);
+    $self->{'mech'}->form_number(2);
     $self->{'mech'}->field('form_loginname', $user);
     $self->{'mech'}->field('form_pw', $pass);
     $self->{'mech'}->click();
 
     if ($self->{'mech'}->content() =~ /\QInvalid\E/) {
-        die '˼Ԥޤ';
+        die 'ログインに失敗しました．';
     }
 }
 
@@ -54,12 +58,12 @@ sub create_release {
     @links = $self->get_release_links();
 
     if (grep($_->text() eq $file_name, @links)) {
-        die 'Ʊ̾Υ꡼¸ߤޤ';
+        die '既に同じ名前のリリースが存在します．';
     }
 
     $self->_mv_create_release_page($package);
 
-    $self->{'mech'}->form_number(1);
+    $self->{'mech'}->form_number(2);
     $self->{'mech'}->field('release_name', $version);
     $self->{'mech'}->field('userfiles[]', $file_path);
     $self->{'mech'}->click();
@@ -67,7 +71,7 @@ sub create_release {
     @links = $self->get_release_links();
 
     unless (grep($_->text() eq $file_name, @links)) {
-        die '꡼κ˼Ԥޤ';
+        die 'リリースの作成に失敗しました．';
     }
 }
 
@@ -96,7 +100,7 @@ sub _mv_list_release_page {
     $self->{'mech'}->get($link->url());
 
     if ($self->{'mech'}->content() !~ /\Q@{[LIST_RELEASE_LABEL]}[0]\E/) {
-        die '꡼ΰڡؤΰư˼Ԥޤ';
+        die 'リリースの一覧ページへの移動に失敗しました．';
     }
 }
 
@@ -109,7 +113,7 @@ sub _mv_edit_release_page {
     $self->{'mech'}->get($link->url());
 
     if ($self->{'mech'}->content() !~ /\Q@{[EDIT_RELEASE_LABEL]}[0]\E/) {
-        die '꡼Խڡؤΰư˼Ԥޤ';
+        die 'リリースの編集ページへの移動に失敗しました．';
     }
 }
 
@@ -120,10 +124,11 @@ sub _mv_create_release_page {
     my $url;
 
     $self->_mv_edit_release_page();
-    $link = $self->{'mech'}->find_link(text => $package);
+    $link = $self->{'mech'}->find_link(text => $package, n => 2) ||
+        $self->{'mech'}->find_link(text => $package, n => 1);
 
     if (! defined $link) {
-        die 'ѥå (' . $package . ') 򸫤ĤޤǤ';
+        die 'パッケージ (' . $package . ') を見つけられませんでした．';
     }
 
     $url = $link->url();
@@ -132,7 +137,7 @@ sub _mv_create_release_page {
     $self->{'mech'}->get($url);
 
     if ($self->{'mech'}->content() !~ /\Q@{[CREATE_RELEASE_LABEL]}[0]\E/) {
-        die '꡼οڡؤΰư˼Ԥޤ';
+        die 'リリースの新規作成ページへの移動に失敗しました．';
     }
 }
 
@@ -140,5 +145,5 @@ sub _mv_create_release_page {
 
 # Local Variables:
 # mode: cperl
-# coding: euc-japan-unix
+# coding: utf-8-unix
 # End:
