@@ -2,8 +2,8 @@
 
 unsetopt FUNCTION_ARGZERO
 
-PACKAGE=`grep AC_INIT configure.in | perl -pe 's/^[^\(]+[^\[]+\[([^\]]+)\].*$/\1/'`
-VERSION=`grep AC_INIT configure.in | perl -pe 's/^[^,]+\D+([\d.]+)\D.*$/\1/' | tr '.' '_'`
+PACKAGE=`grep AC_INIT configure.ac | perl -pe 's/^[^\(]+[^\[]+\[([^\]]+)\].*$/\1/'`
+VERSION=`grep AC_INIT configure.ac | perl -pe 's/^[^,]+\D+([\d.]+)\D.*$/\1/' | tr '.' '_'`
 
 WEB_BASE=/var/www/acapulco.dyndns.org/${PACKAGE}
 CVS_BASE=${HOME}/cvs/${PACKAGE}
