@@ -54,10 +54,10 @@ sub ssh_login {
 sub clean {
     my $exp = shift;
 
-    $exp->send('sudo rm -rf /usr/src/redhat/RPMS/**/mod_uploader-*.rpm .' . "\n");
+    $exp->send('sudo rm -rf /usr/src/redhat/RPMS/**/mod_uploader-*.rpm' . "\n");
     $exp->expect(CMD_TIMEOUT_SEC, HOSTNAME . '%');
 
-    $exp->send('sudo rm -rf /usr/src/redhat/SRPMS/**/mod_uploader-*.rpm .' . "\n");
+    $exp->send('sudo rm -rf /usr/src/redhat/SRPMS/**/mod_uploader-*.rpm' . "\n");
     $exp->expect(CMD_TIMEOUT_SEC, HOSTNAME . '%');
 }
 
